tdxutil: small tools for working with datatypes, data, and exceptions
---------------------------------------------------------------------

In `collections.py` there are some tools for working with lists,
sets, dicts, and iterables more declaratively.

In `data.py` there are some functiions to more concisely read and
write yaml in the most common use cases.

In `exceptions.py` there are some error handling tools. See the
`calldecorators` package if you'd prefer to have a decorator
api.
